#
# spec file for package json-glib
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2009 Dominique Leuenberger, Almere, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           json-glib
VCS: https://src.suse.de/SLFO-pool/json-glib#e38dee03a7b0e3c7856b87d5f844bcc5032399b127cd5e6fe5ce964a8707de46
Version:        1.10.6
Release:        160000.1.6
Summary:        Library for JavaScript Object Notation format
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://live.gnome.org/JsonGlib

Source0:        https://download.gnome.org/sources/json-glib/1.10/%{name}-%{version}.tar.xz
Source99:       baselibs.conf

BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docutils
BuildRequires:  glib2-devel >= 2.54
BuildRequires:  gobject-introspection-devel
BuildRequires:  libxslt-tools
BuildRequires:  meson
BuildRequires:  pkgconfig

%description
JSON-GLib provides a parser and a generator GObject classes and various
wrappers for the complex data types employed by JSON, such as arrays
and objects.

JSON-GLib uses GLib native data types and the generic value container
GValue for ease of development. It also provides integration with the
GObject classes for direct serialization into, and deserialization from,
JSON data streams.

%package -n libjson-glib-1_0-0
Summary:        Library for JavaScript Object Notation format
# To make lang subpackage installable
Group:          Development/Libraries/C and C++
Provides:       %{name} = %{version}

%description -n libjson-glib-1_0-0
JSON is a lightweight data-interchange format. It is comparatively
easy for humans to read and write, and for machines to parse and generate.

JSON-GLib provides a parser and a generator GObject classes and various
wrappers for the complex data types employed by JSON, such as arrays
and objects.

JSON-GLib uses GLib native data types and the generic value container
GValue for ease of development. It also provides integration with the
GObject classes for direct serialization into, and deserialization from,
JSON data streams.

%package -n typelib-1_0-Json-1_0
Summary:        Introspection bindings for libjson-glib
Group:          System/Libraries

%description -n typelib-1_0-Json-1_0
JSON-GLib provides a parser and a generator GObject classes and various
wrappers for the complex data types employed by JSON, such as arrays
and objects.

This package provides the GObject Introspection bindings for JSON-GLib.

%package devel
Summary:        Development files for libjson-glib
Group:          Development/Libraries/C and C++
Requires:       libjson-glib-1_0-0 = %{version}
Requires:       typelib-1_0-Json-1_0 = %{version}

%description devel
JSON-GLib provides a parser and a generator GObject classes and various
wrappers for the complex data types employed by JSON, such as arrays
and objects.

This package contains development files needed to develop with the
json-glib library.

%lang_package

%prep
%setup -q

%build
%meson \
	-Dman=true \
	-Dgtk_doc=disabled \
	%{nil}
%meson_build

%check
%meson_test

%install
%meson_install
%find_lang %{name}-1.0

%post -n libjson-glib-1_0-0 -p /sbin/ldconfig
%postun -n libjson-glib-1_0-0 -p /sbin/ldconfig

%files -n libjson-glib-1_0-0
%license COPYING

%{_libdir}/*.so.*

%files -n typelib-1_0-Json-1_0
%{_libdir}/girepository-1.0/Json-1.0.typelib

%files devel
%doc NEWS README.md
# These could potentially be split in a -tools package, but are never used by non-devs.
%{_bindir}/json-glib-format
%{_bindir}/json-glib-validate
%{_mandir}/man1/json-glib-format.1%{ext_man}
%{_mandir}/man1/json-glib-validate.1%{ext_man}
#
%{_includedir}/%{name}-1.0
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/*.gir
%dir %{_datadir}/installed-tests
%dir %{_libexecdir}/installed-tests
%{_datadir}/installed-tests/json-glib-1.0/
%{_libexecdir}/installed-tests/json-glib-1.0/

%files lang -f %{name}-1.0.lang

%changelog
* Tue Dec 10 2024 bjorn.lie@gmail.com
- Update to version 1.10.6:
  + Allow single quoted strings when running in non-strict mode.
  + Allow escaped characters when running in non-strict mode.
  + Add missing nullable annotation.
* Fri Aug 30 2024 bjorn.lie@gmail.com
- Update to version 1.10.0:
  + Allow disabling installed tests
  + Support parsing multiple root statements in non-strict mode
  + Allow loading files >4GB with json-glib-validate
- Add docutils BuildRequires: New dependency (rst2man)
* Sat Sep 16 2023 bjorn.lie@gmail.com
- Update to version 1.8.0:
  + Build fixes
  + Add current node accessor to JsonReader
  + Make xgettext optional
  + Avoid leaking memory in error paths
  + Update test suite to conform with TAP
  + Ensure valid output for exponential notation of numbers
  + Updated translations.
* Thu Sep 16 2021 sbrabec@suse.com
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Wed Aug 25 2021 bjorn.lie@gmail.com
- Update to version 1.6.6:
  + New release with the documentation and gi-docgen included in
    the archive.
- Drop gtk-doc BuildRequires, no longer needed, nor used.
- Add docbook-xsl-stylesheets and libxslt-tools BuildRequires,
  needed for building of manpages.
* Sat Aug 21 2021 bjorn.lie@gmail.com
- Update to version 1.6.4:
  + Discover linker flags on all toolchains
  + Fix memory leak
  + Use gi-docgen instead of gtk-doc for generating the API
    reference
  + Build against newer versions of GLib
- Pass gtk_doc=disabled to meson, no longer build API
  documentation.
* Tue Feb  9 2021 bjorn.lie@gmail.com
- Update to version 1.6.2:
  + Fix build reproducibility.
  + Fix parsing of UTF-16 surrogate pairs.
  + Ignore UTF-8 BOM.
* Fri Sep 11 2020 bjorn.lie@gmail.com
- Update to version 1.6.0:
  + docs: Add missing index for 1.6 symbols.
  + Updated translations.
- Add gtk-doc BuildRequires and build gtk-doc api documentation and
  manpages via passing man=true and gtk_doc=enabled to meson.
- Add check section and run meson_test macro during build.
- Drop obsolete nuking of .la files, no longer needed.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 1.5.2:
  + Add getters with default fallback for JsonObject.
  + Clarify some expections of the json_object_get_*_member APIs.
  + Fix getting immutable root nodes from empty input.
  + Add `--output` option to json-glib-format.
  + Support loading files via memory mapping.
  + Add a symbol version to all exported symbols.
- Pass -Dgtk_doc=disabled to meson: keep the gtk-doc disabled for
  now.
* Fri May 22 2020 daniel.molkentin@suse.com
- Require pkgconfig to create pkgconfig() provides
* Sat Jan 25 2020 dimstar@opensuse.org
- No longer recommend -lang: supplements are in use
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 1.4.4:
  + Fix memory leaks.
  + Fix behaviour of JsonParser with immutable nodes for empty
    documents.
  + Clarify documentation.
  + Update autoptr macro for JsonNode to use json_node_unref().
  + Update the enumeration types template.
  + Perform fuzzy comparisons for floating point values in the test
    suite.
  + Updated translations.
* Thu Apr 26 2018 sbrabec@suse.com
- Set gettext domain explicitly in translation-update-upstream,
  as it does not support complex meson.build expressions
  (bsc#1087076#c21).
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Sep 12 2017 dimstar@opensuse.org
- Update to version 1.4.2:
  + Literally no change, just a re-released tarball. The tarball
    generated for 1.4.0 and pushed to download.gnome.org comes from
    a different commit.
* Tue Sep 12 2017 dimstar@opensuse.org
- Update to version 1.4.0:
  + Update the linker flags on macOS (bgo#785053).
  + Change the build configuration options to better fit with
    Meson.
  + Updated translations.
* Mon Sep 11 2017 jengelh@inai.de
- Trim descriptions a little. Update summaries.
* Tue Jul 18 2017 zaitor@opensuse.org
- Update to version 1.3.2:
  + Use Meson as the only build system.
  + Bugs fixed: bgo#773504, bgo##780550, bgo#769206, bgo#766281,
    bgo#758580, bgo#768788, bgo#774688.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
* Sun Mar 19 2017 zaitor@opensuse.org
- Update to version 1.2.8:
  + Add missing header in the Meson file listing.
  + Ensure that introspection scans all the headers.
  + build:
  - Reduce the internal dependencies.
  - Add missing argument to the introspection scanner.
  - Ignore 'config.h' when building the API reference.
  - Generate the config.h file under json-glib.
  - Fix soversion for Meson builds.
  - Require the same modules for Meson and Autotools.
  - Sync the interface age with the version.
  + Fix the generated pkg-config file with Meson.
  + docs:
  - Add links to online resources.
  - Reference the JSON-GLib header.
  - Override version macros.
  - Use 'plain' language for JSON snippets.
  - Update the README.
  + Move the reference build down one level.
  + Use the appropriate values to initialize Autotools.
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 1.2.6:
  + Brown paper bag release to re-generate the dist tarball
    (bgo#779980).
- Modernize .spec file a bit: use make %%{?_smp_mflags} and 'find'
  to remove the libtool archives (*.la).
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 1.2.4:
  + Add Meson build system (bgo#773603).
  + Support Visual Studio 2017.
  + Allow using G_DECLARE_INTERFACE with JsonSerializable.
  + Allow empty strings as JsonObject member names (bgo#747279).
* Sat Jul 30 2016 zaitor@opensuse.org
- Update to version 1.2.2:
  + Add support for g_auto* macros.
  + Allow making JSON types optionally immutable, in order to allow
    efficient hashing and equality tests (bgo#756121).
  + Improve the build under MSVC.
  + Updated translations.
* Fri Apr 15 2016 hpj@suse.com
- Update to GNOME 3.20 -- Fate#318572.
* Tue Mar 22 2016 zaitor@opensuse.org
- Update to version 1.2.0:
  + node: Turn a g_debug() call into a JSON_NOTE.
  + debug: Add flag for debugging nodes.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 1.1.2:
  + Add simple wrapper functions for JsonGenerator and JsonParser
    to write and read a string from and to a JsonNode,
    respectively.
  + Drop use of deprecated GIO API.
  + Bump the dependency on GLib to 2.46.
  + Do not create `null` nodes for empty strings (bgo#730803).
  + Documentation fixes (bgo#754384).
  + Avoid crashes in the test suite (bgo#755977).
  + Add simple iterator object for JSON objects (bgo#755509).
  + Detect missing commas in arrays.
  + Add support for g_auto* macros.
  + Allow making JSON types optionally immutable, in order to allow
    efficient hashing and equality tests (bgo#756121).
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 1.0.4:
  + Build fixes.
  + Bugs fixed: bgo#711600, bgo#746143, bgo#724319, bgo#743475,
    bgo#741824, bgo#725972.
  + Updated translations.
* Mon Jun 30 2014 dimstar@opensuse.org
- Update to version 1.0.2:
  + Build fixes.
  + Bugs fixed: bgo#727593, bgo#727755, bgo#730425, bgo#730917.
  + Updated translations.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 1.0.0:
  + Build fixes.
  + Bugs fixed: bgo#723813.
  + Updated translations.
* Tue Feb  4 2014 dimstar@opensuse.org
- Update to version 0.99.2:
  + Use the -Bsymbolic-functions linker flag when available.
  + Bump the dependency on GLib to 2.38.
  + Use the TAP driver for the test suite.
  + Improve the syntax validation in JsonPath.
  + Validate the JsonParser input to be UTF-8.
  + Add command line tools for validating and formatting JSON.
  + Improve documentation.
* Sat Sep 21 2013 dimstar@opensuse.org
- Update to version 0.16.2:
  + Use the -Bsymbolic-functions linker flag when available.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 0.16.0:
  + docs: Fix xinclude fallback for annotation glossary.
  + variant: Fix documentation and annotations for deserialize().
  + Update Visual Studio Solution Files.
  + Visual Studio Builds: Support building introspection files.
  + path: Fix get all object members with wildcard.
  + build: Bump up the requirement for GLib.
  + build: Use the symbols file to generate our public ABI.
  + Use the new typed JsonNode initializers.
  + Consolidate null handling in JsonArray and JsonObject.
  + node: Add typed initializers.
  + Bugs fixed: bgo#660795, bgo#686096, bgo#691557, bgo#693575.
  + Updated translations.
* Thu Feb 28 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 0.15.2:
  + Fixes for building with VisualStudio
  + Allow out-of-tree builds
  + Bump the dependency on GLib to 2.31
  + Use the new deprecation system provided by GLib
  + Simplify the value handling inside JsonNode
  + Use lcov to generate coverage reports for the test suite
  + Check expected ABI when building
  + Drop dependency on gnome-autogen.sh when building from Git
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-Json-1_0 subpackage.
- Add typelib-1_0-Json-1_0 Requires to devel subpackage.
* Fri Oct 28 2011 dimstar@opensuse.org
- Update to version 0.14.2:
  + Build fixes for compiling against the latest GLib
  + Documentation fixes
* Mon Sep 19 2011 vuntz@opensuse.org
- Update to version 0.14.0:
  + Add translations.
- Create lang subpackage.
- Add json-glib-lang Recommends to libjson-glib-1_0-0, as well as a
  json-glib Provides to make the lang subpackage installable.
* Fri Sep  9 2011 vuntz@opensuse.org
- Update to version 0.13.90:
  + Make JsonReader perform a stricter validation especially when
    using the strongly typed accessors.
  + Misc bug fixes.
* Wed Jul 27 2011 vuntz@opensuse.org
- Add baselibs.conf.
* Wed Jun 15 2011 dimstar@opensuse.org
- Update to version 0.13.4:
  + Remove all G_CONST_RETURN usage after the deprecation
  + Allow JsonSerializable to override the introspection and
    modification of properties
  + Add i18n support for GError messages
  + Do not serialize GObject properties that match their default
    values.
* Wed May 18 2011 dimstar@opensuse.org
- Update to version 0.13.2:
  + Bump the dependency on GLib to 2.26
  + Allow building on Windows using VisualStudio
  + Add JSON ↔ GVariant translation
  + Improve sanity checks when (de)serializing GObject properties
  + Add missing introspection annotations
  + Add JsonReader.list_members()
  + Allow using JsonReader.read_element() on JSON objects
  + Documentation fixes.
* Wed May  4 2011 vuntz@opensuse.org
- Update to version 0.12.4:
  + Fix a bug in JsonObject that led to memory corruption when
    replacing members.
  + Fix introspection annotations.
  + Use AC_CANONICAL_HOST when building, to ease cross-compiling.
  + List GIO in the Requires: clause of the pkg-config file
* Fri Feb 11 2011 fcrozat@novell.com
- Update to version 0.12.2:
  + Implement support for bare values in JsonGenerator
  + Do not require GLib 2.20 for the test suite
  + Do not lose precision when serializing floating point values
  + Improve introspection data
* Sat Sep 25 2010 vuntz@opensuse.org
- Update to version 0.12.0:
  + Add JsonReader, a convenience API for cursor-based parsing of
    JSON trees
  + Depend on GObject-Introspection 0.9.5
* Sat Sep 18 2010 vuntz@opensuse.org
- Move gir files to devel subpackage.
* Mon Aug  2 2010 dimstar@opensuse.org
- Update to version 0.11.2:
  + On the way to 0.12.0:
  - Support surrogate pairs in JSON strings
  - Update the test suite
  - Add (optional) coverage reports
  - Improve strictness of JsonParser
  - Improve error reporting of JsonParser
  - Add JsonBuilder, a convenience API for programmatic building
    of JSON trees
  - Add methods for JsonParser and JsonGenerator to handle
    Input|OutputStream objects coming from GIO.
- Remove glib2-devel Requires from the devel package. RPM handles
  this automatically by pkgconfig requires now.
* Fri Mar 19 2010 dimstar@opensuse.org
- Update to version 0.10.4:
  + Improve the strictness of the JsonParser code by refactoring a
    large chunk of it
  + Fix JsonGenerator when dumping nodes with a floating point
    value
  + Add negative conformance test cases
* Fri Feb 26 2010 dimstar@opensuse.org
- Update to version 0.10.2:
  + Documentation fixes for GBoxed transformation functions
  + Zero all fields of JsonObject on creation
* Sat Jan  2 2010 vuntz@opensuse.org
- Update to version 0.10.0:
  + Build fixes.
- Drop json-glib-fix-build.patch: fixed upstream.
* Sun Dec 27 2009 vuntz@opensuse.org
- Update to version 0.9.2:
  + Fix generation of doubles
  + Add more units to the test suite
  + Add JsonNode macros for quick type checking
  + Guarantee insertion order when parsing and generating JSON
    Objects
  + Serialize GParamSpecObject properties
  + Add serialization and deserialization for GBoxed types
  + Add API for serializing GObjects to, and deserializing from,
    JsonNode
  + Build environment fixes
  + Documentation fixes
  + Generate correct introspection data
  + Make JsonSerializable in complete control of deserialization
- Changes from version 0.8.0:
  + Remove the in-tree Vala bindings: they are part of Vala, now
  + Remove the in-tree Debian packaging
  + Fix: JsonGenerator does not escape special characters
  + Fix: Conditionally compile the test suite
  + Display the filename and line inside the error messages when
    loading from a file
  + Fix: Correctly terminate a string array
  + Fix: Regression tests fail on OpenBSD
  + Do not leak memory on error code paths
  + Improve and clean up the build system
  + Make JsonNode completely opaque
  + Conditionally generate introspection data on build
  + Fix: Do not overwrite when copying
  + Deprecate json_object_add_member()
  + Add convenience accessors for JsonObject and JsonArray
  + Add convenience iteration functions for JsonObject and
    JsonArray
  + Automatically promote integers to gint64, to compensate for the
    lack of integer size in the JSON specificiation
  + Disallow the inclusion of single header files: only json-glib.h
    and json-gobject.h can be included directly
  + Documentation fixes
  + Clean up and remove code duplication inside the Parser object
- Add gobject-introspection-devel BuildRequires.
- Add json-glib-fix-build.patch to fix build.
* Sat Jun 13 2009 vuntz@novell.com
- Also package AUTHORS ChangeLog COPYING NEWS README.
* Tue May 19 2009 dominique-obs@leuenberger.net
- Specfile cleanups.
* Wed Mar 25 2009 dominique@leuenberger.net
- Initial package of 0.6.2 for openSUSE
